@@ -17,7 +17,7 @@ from .services import DB_INSTANCES, DB_CREDENTIALS
 from .textfile import TextFile
 
 
-def getSelects(sql):
+def get_selects(sql):
     sqlSelect = sql[sql.find("select") + 6:sql.find("from")]
     i = 0
     stack = []
@@ -45,6 +45,11 @@ class Database(object):
     Tots els mètodes es poden utilitzar per Oracle i MariaDB
     si no s'especifica el contrari.
     """
+
+    def set_debug(self):
+        self.DEBUG = True
+
+    DEBUG = False
     NUM2L = (["01", "02", "03", "04", "05", "06", "07", "08", "09", "10",
               "11", "12", "13", "14", "15", "16", "17", "18", "19", "20",
               "21", "22", "23", "24", "25", "26", "27", "28", "29", "30"])
@@ -56,6 +61,7 @@ class Database(object):
         'dat': (lambda: str(random.randint(2000, 2020)) + random.choice(Database.NUM2L[0:12]) + random.choice(Database.NUM2L)),
         'naix': (lambda: str(random.randint(1930, 2005)) + random.choice(Database.NUM2L[0:12]) + random.choice(Database.NUM2L)),
         'id': (lambda: random.randint(1, 6)),
+        'id_cip': (lambda: random.randint(1, 6)),
         'codi': (lambda: random.choice(["TT101", "TT102", "TT103", "Q78544", "Q03566", "Q03585", "N19627", "N19640", "N19685", "N18427", "N18440", "N18485", "G76211", "G40291", "013731", "G40111", "Q85544", "Q75958", "W29485", "Q85585", "N18542", "N18527", "N18540", "N18585", "009780", "013110"])),
         'descripcio': (lambda: "lorem ipsum algo no se que cosas latin"),
         'des': (lambda: "lorem ipsum otro algo no se latin"),
@@ -83,10 +89,14 @@ class Database(object):
             self.local_infile = attributes['local_infile']
 
     def generate_one(self, sql):
-        sqlSelect = getSelects(sql)
+        sqlSelect = get_selects(sql)
         data = {}
+        if self.DEBUG:
+            print(sqlSelect)
         if len(sqlSelect) > 0:
             for select in sqlSelect:
+                while select in data:
+                    select = select + "_aux"
                 if select in Database.TEMPLATE:
                     if select == 'cod':
                         info = random.choice(Database.TEMPLATE[select])
@@ -100,6 +110,9 @@ class Database(object):
                              if x[0] in sqlSelect else
                              len(sqlSelect) + 1)
         result = tuple(map(lambda d: d[1], sorted_data))
+        if self.DEBUG:
+            print(data)
+            print(sorted_data)
         return result[0:len(sqlSelect)]
 
     def connect(self, existent=True):
@@ -408,71 +421,56 @@ class Database(object):
         param = {'column': column, 'length': length,
                  'precision': precision, 'scale': scale,
                  'done': done, 'char': char, 'num': num}
-        conv = {('my', 'date', 'my', 'create'): '{column} {done}',
-                ('my', 'date', 'my', 'query'):
-                    "date_format({column}, '%Y%m%d')",
-                ('my', 'date', 'ora', 'create'): '{column} date',
-                ('my', 'date', 'ora', 'query'): column,
-                ('my', 'int', 'my', 'create'): '{column} {done}',
-                ('my', 'int', 'my', 'query'): column,
-                ('my', 'int', 'ora', 'create'): '{column} number({num})',
-                ('my', 'int', 'ora', 'query'): column,
-                ('my', 'bigint', 'my', 'create'): '{column} {done}',
-                ('my', 'bigint', 'my', 'query'): column,
-                ('my', 'bigint', 'ora', 'create'): '{column} number({num})',
-                ('my', 'bigint', 'ora', 'query'): column,
-                ('my', 'double', 'my', 'create'): '{column} {done}',
-                ('my', 'double', 'my', 'query'): column,
-                ('my', 'double', 'ora', 'create'): '{column} number({num})',
-                ('my', 'double', 'ora', 'query'): column,
-                ('my', 'varchar', 'my', 'create'): '{column} {done}',
-                ('my', 'varchar', 'my', 'query'): column,
-                ('my', 'varchar', 'ora', 'create'):
-                    '{column} varchar2({char})',
-                ('my', 'varchar', 'ora', 'query'): column,
-                ('ora', 'DATE', 'my', 'create'): '{column} date',
-                ('ora', 'DATE', 'my', 'query'):
-                    "to_char({column}, 'YYYYMMDD')",
-                ('ora', 'DATE', 'ora', 'create'): '{column} date',
-                ('ora', 'DATE', 'ora', 'query'): column,
-                ('ora', 'DATE_J', 'my', 'create'): '{column} date',
-                ('ora', 'DATE_J', 'my', 'query'):
-                    "to_char(to_date({column}, 'J'), 'YYYYMMDD')",
-                ('ora', 'DATE_J', 'ora', 'create'): '{column} date',
-                ('ora', 'DATE_J', 'ora', 'query'): "to_date({column}, 'J')",
-                ('ora', 'DATETIME', 'my', 'create'): '{column} datetime',
-                ('ora', 'DATETIME', 'my', 'query'):
-                    "to_char({column}, 'YYYY-MM-DD HH24:MI:SS')",
-                ('ora', 'DATETIME', 'ora', 'create'): '{column} date',
-                ('ora', 'DATETIME', 'ora', 'query'): column,
-                ('ora', 'TIMESTAMP(6)', 'my', 'create'): '{column} datetime',
-                ('ora', 'TIMESTAMP(6)', 'my', 'query'):
-                    "to_char({column}, 'YYYY-MM-DD HH24:MI:SS')",
-                ('ora', 'TIMESTAMP(6)', 'ora', 'create'): '{column} date',
-                ('ora', 'TIMESTAMP(6)', 'ora', 'query'): column,
-                ('ora', 'NUMBER', 'my', 'create'):
-                    '{column} double' if scale
-                    else '{column} int' if not precision or precision < 10
-                    else '{column} bigint',
-                ('ora', 'NUMBER', 'my', 'query'): column,
-                ('ora', 'NUMBER', 'ora', 'create'):
-                    '{column} number({precision}, {scale})' if scale
-                    else '{column} number',
-                ('ora', 'NUMBER', 'ora', 'query'): column,
-                ('ora', 'VARCHAR2', 'my', 'create'):
-                    "{column} varchar({length})",
-                ('ora', 'VARCHAR2', 'my', 'query'):
-                    'ltrim(rtrim({column}))' if length > 49 else column,
-                ('ora', 'VARCHAR2', 'ora', 'create'):
-                    '{column} varchar2({length})',
-                ('ora', 'VARCHAR2', 'ora', 'query'): column,
-                ('ora', 'CHAR', 'my', 'create'):
-                    "{column} varchar({length})",
-                ('ora', 'CHAR', 'my', 'query'):
-                    'ltrim(rtrim({column}))' if length > 49 else column,
-                ('ora', 'CHAR', 'ora', 'create'):
-                    '{column} char({length})',
-                ('ora', 'CHAR', 'ora', 'query'): column}
+        conv = {
+            ('my', 'date', 'my', 'create'): '{column} {done}',
+            ('my', 'date', 'my', 'query'): "date_format({column}, '%Y%m%d')",
+            ('my', 'date', 'ora', 'create'): '{column} date',
+            ('my', 'date', 'ora', 'query'): column,
+            ('my', 'int', 'my', 'create'): '{column} {done}',
+            ('my', 'int', 'my', 'query'): column,
+            ('my', 'int', 'ora', 'create'): '{column} number({num})',
+            ('my', 'int', 'ora', 'query'): column,
+            ('my', 'bigint', 'my', 'create'): '{column} {done}',
+            ('my', 'bigint', 'my', 'query'): column,
+            ('my', 'bigint', 'ora', 'create'): '{column} number({num})',
+            ('my', 'bigint', 'ora', 'query'): column,
+            ('my', 'double', 'my', 'create'): '{column} {done}',
+            ('my', 'double', 'my', 'query'): column,
+            ('my', 'double', 'ora', 'create'): '{column} number({num})',
+            ('my', 'double', 'ora', 'query'): column,
+            ('my', 'varchar', 'my', 'create'): '{column} {done}',
+            ('my', 'varchar', 'my', 'query'): column,
+            ('my', 'varchar', 'ora', 'create'): '{column} varchar2({char})',
+            ('my', 'varchar', 'ora', 'query'): column,
+            ('ora', 'DATE', 'my', 'create'): '{column} date',
+            ('ora', 'DATE', 'my', 'query'): "to_char({column}, 'YYYYMMDD')",
+            ('ora', 'DATE', 'ora', 'create'): '{column} date',
+            ('ora', 'DATE', 'ora', 'query'): column,
+            ('ora', 'DATE_J', 'my', 'create'): '{column} date',
+            ('ora', 'DATE_J', 'my', 'query'): "to_char(to_date({column}, 'J'), 'YYYYMMDD')",
+            ('ora', 'DATE_J', 'ora', 'create'): '{column} date',
+            ('ora', 'DATE_J', 'ora', 'query'): "to_date({column}, 'J')",
+            ('ora', 'DATETIME', 'my', 'create'): '{column} datetime',
+            ('ora', 'DATETIME', 'my', 'query'): "to_char({column}, 'YYYY-MM-DD HH24:MI:SS')",
+            ('ora', 'DATETIME', 'ora', 'create'): '{column} date',
+            ('ora', 'DATETIME', 'ora', 'query'): column,
+            ('ora', 'TIMESTAMP(6)', 'my', 'create'): '{column} datetime',
+            ('ora', 'TIMESTAMP(6)', 'my', 'query'): "to_char({column}, 'YYYY-MM-DD HH24:MI:SS')",
+            ('ora', 'TIMESTAMP(6)', 'ora', 'create'): '{column} date',
+            ('ora', 'TIMESTAMP(6)', 'ora', 'query'): column,
+            ('ora', 'NUMBER', 'my', 'create'): '{column} double',
+            ('ora', 'NUMBER', 'my', 'query'): column,
+            ('ora', 'NUMBER', 'ora', 'create'): '{column} number({precision}, {scale})',
+            ('ora', 'NUMBER', 'ora', 'query'): column,
+            ('ora', 'VARCHAR2', 'my', 'create'): "{column} varchar({length})",
+            ('ora', 'VARCHAR2', 'my', 'query'): 'ltrim(rtrim({column}))',
+            ('ora', 'VARCHAR2', 'ora', 'create'): '{column} varchar2({length})',
+            ('ora', 'VARCHAR2', 'ora', 'query'): column,
+            ('ora', 'CHAR', 'my', 'create'): "{column} varchar({length})",
+            ('ora', 'CHAR', 'my', 'query'): 'ltrim(rtrim({column}))',
+            ('ora', 'CHAR', 'ora', 'create'): '{column} char({length})',
+            ('ora', 'CHAR', 'ora', 'query'): column
+        }
         resul = {key: conv[(self.engine, type, desti, key)].format(**param)
                  for key in ('create', 'query')}
         return resul
